package sk.upjs.ics.currencr;

import java.math.BigDecimal;

import android.app.Activity;
import android.os.Bundle;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.View;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemSelectedListener;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.TextView;

public class MainActivity extends Activity {

	private EditText amountEditText;
	private Spinner currencySpinner;
	private EuroCurrencyConverter currencyConverter;
	private TextView resultTextView;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		currencyConverter = new EuroCurrencyConverter(); 
		
		amountEditText = (EditText) findViewById(R.id.amountEditText);
		currencySpinner = (Spinner) findViewById(R.id.currencySpinner);
		
		resultTextView = (TextView) findViewById(R.id.resultTextView);

		amountEditText.addTextChangedListener(new TextWatcher() {
			@Override
			public void onTextChanged(CharSequence s, int start, int before, int count) {
				convertCurrency();				
			}
			
			@Override
			public void beforeTextChanged(CharSequence s, int start, int count,
					int after) {
				// no-op
			}
			
			@Override
			public void afterTextChanged(Editable s) {
				// no-op
			}
		});
		
		currencySpinner.setOnItemSelectedListener(new OnItemSelectedListener() {

			@Override
			public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
				convertCurrency();			}

			@Override
			public void onNothingSelected(AdapterView<?> parent) {
				// do nothing
			}
		});
	}

	
	protected void convertCurrency() {
		try {
			String selectedCurrency = (String) currencySpinner.getSelectedItem();
			if(selectedCurrency == null) {
				return;
			}
			BigDecimal amount = new BigDecimal(amountEditText.getText().toString());
			
			BigDecimal conversionResult = currencyConverter.convert(selectedCurrency, amount);
			
			resultTextView.setText(conversionResult.toString());
		} catch (NumberFormatException e) {
			resultTextView.setText(R.string.illegal_conversion);
		}
	}
}
